@@ -41,6 +41,13 @@ def getPost(channel, existing_file, min_time = None, max_time = None):
             continue
         return post
 
+def getPendingPosts(channel, existing_file, min_time = None, max_time = None):
+    for post in getPosts(channel, min_time, max_time):
+        key = 'https://t.me/' + post.getKey()
+        if existing_file.get(key):
+            continue
+        yield post
+
 async def getChannelImp(client, channel):
     if 'id_map' not in credential:
         credential['id_map'] = {}
@@ -117,7 +124,8 @@ async def exitTelethon():
 def getText(soup):
     soup = copy.copy(soup)
     for item in soup.find_all('a'):
-        if item.get('href') and not isUrl(item.text):
+        if (item.get('href') and not isUrl(item.text) and 
+                not item.get('href').startswith('?q=')):
             item.replace_with('\n\n' + item.get('href') + '\n\n')
     for item in soup.find_all('br'):
         item.replace_with('\n')
